@@ -432,7 +432,7 @@ def common_startElement(obj, name, attrs):
             obj._rule_error = True
             return True
         value = attrs["value"]
-        obj._limit_ok.limit = rich.Rich_Limit(value)
+        obj._limit_ok.limit = rich.Rich_Limit(value, attrs.get("burst"))
     else:
         return False
 
@@ -580,6 +580,14 @@ def common_check_config(obj, config, item, all_config, all_io_objects):
                     )
 
 
+def _handler_add_rich_limit(handler, limit):
+    d = {"value": limit.value}
+    burst = limit.burst
+    if burst is not None:
+        d["burst"] = str(burst)
+    handler.simpleElement("limit", d)
+
+
 def common_writer(obj, handler):
     # short
     if obj.short and obj.short != "":
@@ -742,15 +750,14 @@ def common_writer(obj, handler):
                     attrs["prefix"] = rule.log.prefix
                 if rule.log.level:
                     attrs["level"] = rule.log.level
+                handler.ignorableWhitespace("    ")
                 if rule.log.limit:
-                    handler.ignorableWhitespace("    ")
                     handler.startElement("log", attrs)
                     handler.ignorableWhitespace("\n      ")
-                    handler.simpleElement("limit", {"value": rule.log.limit.value})
+                    _handler_add_rich_limit(handler, rule.log.limit)
                     handler.ignorableWhitespace("\n    ")
                     handler.endElement("log")
                 else:
-                    handler.ignorableWhitespace("    ")
                     handler.simpleElement("log", attrs)
                 handler.ignorableWhitespace("\n")
             else:
@@ -761,30 +768,28 @@ def common_writer(obj, handler):
                     attrs["prefix"] = rule.log.prefix
                 if rule.log.threshold:
                     attrs["queue-size"] = rule.log.threshold
+                handler.ignorableWhitespace("    ")
                 if rule.log.limit:
-                    handler.ignorableWhitespace("    ")
                     handler.startElement("nflog", attrs)
                     handler.ignorableWhitespace("\n      ")
-                    handler.simpleElement("limit", {"value": rule.log.limit.value})
+                    _handler_add_rich_limit(handler, rule.log.limit)
                     handler.ignorableWhitespace("\n    ")
                     handler.endElement("nflog")
                 else:
-                    handler.ignorableWhitespace("    ")
                     handler.simpleElement("nflog", attrs)
                 handler.ignorableWhitespace("\n")
 
         # audit
         if rule.audit:
             attrs = {}
+            handler.ignorableWhitespace("    ")
             if rule.audit.limit:
-                handler.ignorableWhitespace("    ")
                 handler.startElement("audit", {})
                 handler.ignorableWhitespace("\n      ")
-                handler.simpleElement("limit", {"value": rule.audit.limit.value})
+                _handler_add_rich_limit(handler, rule.audit.limit)
                 handler.ignorableWhitespace("\n    ")
                 handler.endElement("audit")
             else:
-                handler.ignorableWhitespace("    ")
                 handler.simpleElement("audit", attrs)
             handler.ignorableWhitespace("\n")
 
@@ -805,15 +810,14 @@ def common_writer(obj, handler):
                 attrs["set"] = rule.action.set
             else:
                 log.warning("Unknown action '%s'", type(rule.action))
+            handler.ignorableWhitespace("    ")
             if rule.action.limit:
-                handler.ignorableWhitespace("    ")
                 handler.startElement(action, attrs)
                 handler.ignorableWhitespace("\n      ")
-                handler.simpleElement("limit", {"value": rule.action.limit.value})
+                _handler_add_rich_limit(handler, rule.action.limit)
                 handler.ignorableWhitespace("\n    ")
                 handler.endElement(action)
             else:
-                handler.ignorableWhitespace("    ")
                 handler.simpleElement(action, attrs)
             handler.ignorableWhitespace("\n")
 
@@ -828,23 +832,23 @@ class Policy(IO_Object):
     priority_default = DEFAULT_POLICY_PRIORITY
     priority_reserved = [0]
 
-    IMPORT_EXPORT_STRUCTURE = (
-        ("version", ""),  # s
-        ("short", ""),  # s
-        ("description", ""),  # s
-        ("target", ""),  # s
-        ("services", [""]),  # as
-        ("ports", [("", "")]),  # a(ss)
-        ("icmp_blocks", [""]),  # as
-        ("masquerade", False),  # b
-        ("forward_ports", [("", "", "", "")]),  # a(ssss)
-        ("rich_rules", [""]),  # as
-        ("protocols", [""]),  # as
-        ("source_ports", [("", "")]),  # a(ss)
-        ("priority", 0),  # i
-        ("ingress_zones", [""]),  # as
-        ("egress_zones", [""]),  # as
-    )
+    IMPORT_EXPORT_STRUCTURE = {
+        "version": "",  # s
+        "short": "",  # s
+        "description": "",  # s
+        "target": "",  # s
+        "services": [""],  # as
+        "ports": [("", "")],  # a(ss)
+        "icmp_blocks": [""],  # as
+        "masquerade": False,  # b
+        "forward_ports": [("", "", "", "")],  # a(ssss)
+        "rich_rules": [""],  # as
+        "protocols": [""],  # as
+        "source_ports": [("", "")],  # a(ss)
+        "priority": 0,  # i
+        "ingress_zones": [""],  # as
+        "egress_zones": [""],  # as
+    }
     ADDITIONAL_ALNUM_CHARS = ["_", "-", "/"]
     PARSER_REQUIRED_ELEMENT_ATTRS = {
         "short": None,
@@ -882,6 +886,7 @@ class Policy(IO_Object):
         "nflog": ["group", "prefix", "queue-size"],
         "reject": ["type"],
         "tcp-mss-clamp": ["value"],
+        "limit": ["burst"],
     }
 
     def __init__(self):
