@@ -1,30 +1,15 @@
-# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 # Copyright (C) 2013-2016 Red Hat, Inc.
 #
 # Authors:
 # Thomas Woerner <twoerner@redhat.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 
-__all__ = [ "LastUpdatedOrderedDict" ]
 
-class LastUpdatedOrderedDict(object):
+class LastUpdatedOrderedDict:
     def __init__(self, x=None):
-        self._dict = { }
-        self._list = [ ]
+        self._dict = {}
+        self._list = []
         if x:
             self.update(x)
 
@@ -33,7 +18,7 @@ class LastUpdatedOrderedDict(object):
         self._dict.clear()
 
     def update(self, x):
-        for key,value in x.items():
+        for key, value in x.items():
             self[key] = value
 
     def items(self):
@@ -45,8 +30,10 @@ class LastUpdatedOrderedDict(object):
             del self._dict[key]
 
     def __repr__(self):
-        return '%s([%s])' % (self.__class__.__name__, ', '.join(
-                ['(%r, %r)' % (key, self[key]) for key in self._list]))
+        return "%s([%s])" % (
+            self.__class__.__name__,
+            ", ".join(["(%r, %r)" % (key, self[key]) for key in self._list]),
+        )
 
     def __setitem__(self, key, value):
         if key not in self._dict:
@@ -54,7 +41,7 @@ class LastUpdatedOrderedDict(object):
         self._dict[key] = value
 
     def __getitem__(self, key):
-        if type(key) == int:
+        if isinstance(key, int):
             return self._list[key]
         else:
             return self._dict[key]
@@ -69,7 +56,7 @@ class LastUpdatedOrderedDict(object):
         return self._list[:]
 
     def values(self):
-        return [ self[key] for key in self._list ]
+        return [self[key] for key in self._list]
 
     def setdefault(self, key, value=None):
         if key in self:
